@@ -1,15 +1,16 @@
 package Quantum::Superpositions::Lazy::Role::Collapsible;
 
-our $VERSION = '1.02';
+our $VERSION = '1.03';
 
-use v5.28; use warnings;
+use v5.28;
+use warnings;
 use Moo::Role;
 
 use feature qw(signatures);
 no warnings qw(experimental::signatures);
 
-use Quantum::Superpositions::Lazy::Operation::ComputationalOp;
-use Quantum::Superpositions::Lazy::Operation::LogicOp;
+use Quantum::Superpositions::Lazy::Operation::Computational;
+use Quantum::Superpositions::Lazy::Operation::Logical;
 use Quantum::Superpositions::Lazy::Computation;
 use Quantum::Superpositions::Lazy::State;
 use Quantum::Superpositions::Lazy::Statistics;
@@ -18,10 +19,10 @@ use List::Util qw(reduce);
 use Carp qw(croak);
 
 my %mathematical = map { $_ => 1 }
-	Quantum::Superpositions::Lazy::Operation::ComputationalOp->supported_types;
+	Quantum::Superpositions::Lazy::Operation::Computational->supported_types;
 
 my %logical = map { $_ => 1 }
-	Quantum::Superpositions::Lazy::Operation::LogicOp->supported_types;
+	Quantum::Superpositions::Lazy::Operation::Logical->supported_types;
 
 sub create_computation ($type, @args)
 {
@@ -33,7 +34,7 @@ sub create_computation ($type, @args)
 
 sub create_logic ($type, @args)
 {
-	my $op = Quantum::Superpositions::Lazy::Operation::LogicOp->new(
+	my $op = Quantum::Superpositions::Lazy::Operation::Logical->new(
 		sign => $type,
 	);
 
@@ -45,7 +46,7 @@ sub create_logic ($type, @args)
 	}
 }
 
-sub _operate(@args)
+sub _operate (@args)
 {
 	my $type = pop @args;
 
@@ -83,12 +84,12 @@ has "stats" => (
 	is => "ro",
 	isa => InstanceOf ["Quantum::Superpositions::Lazy::Statistics"],
 	lazy => 1,
-	default => sub ($self) { Quantum::Superpositions::Lazy::Statistics->new(parent => $self) },
+	default => sub ($self) { $Quantum::Superpositions::Lazy::Statistics::implementation->new(parent => $self) },
 	init_arg => undef,
 	clearer => "_clear_stats",
 );
 
-sub states($self)
+sub states ($self)
 {
 	return $self->_complete_states;
 }
@@ -123,7 +124,7 @@ sub transform ($self, $coderef)
 	return $self->operate("_transform", $coderef, undef);
 }
 
-sub to_ket_notation($self)
+sub to_ket_notation ($self)
 {
 	return join " + ", map {
 		($_->weight / $self->weight_sum) . "|" .
