@@ -1,8 +1,9 @@
 package Quantum::Superpositions::Lazy::Util;
 
-our $VERSION = '1.02';
+our $VERSION = '1.03';
 
-use v5.28; use warnings;
+use v5.28;
+use warnings;
 use feature qw(signatures);
 no warnings qw(experimental::signatures);
 
@@ -16,12 +17,12 @@ our @EXPORT_OK = qw(
 	get_rand
 );
 
-sub is_collapsible($item)
+sub is_collapsible ($item)
 {
 	return blessed $item && $item->DOES("Quantum::Superpositions::Lazy::Role::Collapsible");
 }
 
-sub is_state($item)
+sub is_state ($item)
 {
 	return blessed $item && $item->isa("Quantum::Superpositions::Lazy::State");
 }
